'use strict';

var shared = require('./shared-edae394d.js');

const plugin = (options = {}) => {
    const opts = shared.getConfig(options);
    const satisfyPropList = shared.createPropListMatcher(opts.propList);
    const exclude = opts.exclude;
    let isExcludeFile = false;
    let pxReplace;
    const rpxRegex = shared.pxRegex(['rpx']);
    return {
        postcssPlugin: shared.postcssPlugin,
        Once(css) {
            var _a;
            const source = css.source;
            const filePath = source.input.file;
            if (exclude &&
                ((typeof exclude === 'function' && exclude(filePath)) ||
                    (typeof exclude === 'string' && filePath.indexOf(exclude) !== -1) ||
                    exclude.exec(filePath) !== null)) {
                isExcludeFile = true;
            }
            else {
                isExcludeFile = false;
            }
            const rootValue = typeof opts.rootValue === 'function'
                ? opts.rootValue(source.input)
                : opts.rootValue;
            pxReplace = shared.createPxReplace(rootValue, opts.unitPrecision, opts.minValue, opts.transformUnit)((_a = css.source) === null || _a === void 0 ? void 0 : _a.input);
        },
        Declaration(decl) {
            if (isExcludeFile)
                return;
            if (decl.value.indexOf('rpx') === -1 ||
                !satisfyPropList(decl.prop) ||
                // @ts-ignore
                shared.blacklistedSelector(opts.selectorBlackList, decl.parent.selector)) {
                return;
            }
            const value = decl.value.replace(rpxRegex, pxReplace);
            // if rpx unit already exists, do not add or replace
            // @ts-ignore
            if (shared.declarationExists(decl.parent, decl.prop, value))
                return;
            if (opts.replace) {
                decl.value = value;
            }
            else {
                decl.cloneAfter({ value });
            }
        },
        AtRule(atRule) {
            if (isExcludeFile)
                return;
            if (opts.mediaQuery && atRule.name === 'media') {
                if (atRule.params.indexOf('rpx') === -1)
                    return;
                atRule.params = atRule.params.replace(rpxRegex, pxReplace);
            }
        }
    };
};
plugin.postcss = true;

module.exports = plugin;
